====
GyPS
====

A GPS files toolbox written in Python3.


Features
========

* Transcoding of some file formats (GPX, KML, FIT, SBN, SBP)
* Lossless merging of SBN or SBP files
* Compute statistics (segmented tracks supported)
* Automatic file renaming according to a given pattern like log's start date for
  example
* Maintain a local SQLite database for a given folder full of GPS files
* Photo mapping in a KML file, for one or several GPS tracks
* Configurable via both an ``.ini`` file and command line flags (merged)


License
=======

This project is distributed under the terms of the MIT license.
See the `LICENSE.txt <LICENSE.txt>`_ file for details.
